@@ -699,7 +699,6 @@ struct ConfigAuth {
     allow_anonymous: bool,
     password_file: Option<String>,
     key_file: Option<String>,
-    aes_nonce: Option<String>,
     acl: String,
 }
 
@@ -988,7 +987,7 @@ async fn process_udp_packet(frame: Vec<u8>) -> Result<bool, (Error, bool)> {
             .auth_and_decr(
                 sp.next()
                     .ok_or_else(|| (Error::invalid_data("encryption block missing"), false))?,
-                login,
+                if login.is_empty() { "_" } else { login },
                 etp,
             )
             .map_err(|e| (e, false))?;
@@ -1230,12 +1229,6 @@ fn main() {
             let mut keys = KEY_DB.write().await;
             let key_file = format_path!(f.clone());
             keys.set_key_file(&key_file);
-            keys.set_nonce(config.auth.aes_nonce.as_ref().map(|h| {
-                hex::decode(h)
-                    .expect("unable to parse nonce")
-                    .try_into()
-                    .expect("invalid nonce size (12 bytes required)")
-            }));
             reload_db!(keys);
         }
         handle_term_signal!(SignalKind::interrupt(), false);
